@@ -49,7 +49,7 @@ class TestParseBase64QueryString(unittest.TestCase):
         ]
 
         for test_dict in TEST_DICTS_AND_RESULTS:
-            self.assertEquals(test_dict[0], QueryStringManager.parse_base64_query_string(test_dict[1]))
+            self.assertEqual(test_dict[0], QueryStringManager.parse_base64_query_string(test_dict[1]))
 
 
     def test_parse_multiple_arg_query_string(self):
@@ -66,4 +66,4 @@ class TestParseBase64QueryString(unittest.TestCase):
         ]
 
         for test_dict in TEST_DICTS_AND_RESULTS:
-            self.assertEquals(test_dict[0], QueryStringManager.parse_base64_query_string(test_dict[1]))
+            self.assertEqual(test_dict[0], QueryStringManager.parse_base64_query_string(test_dict[1]))
